pub enum TaxMethod {
Exclusive,
Inclusive,
None,
}Expand description
The tax option to be applied to the products. When using inclusive, the tax percentage will already be included in the price. When using exclusive, the tax will not be included in the price. When using none, no tax will be added. Use the tax field for defining the tax percentage amount.
Variants